// src/vscode.ts
import JSZip from "jszip";
import { ofetch } from "ofetch";
import resolvePath from "resolve-pathname";
import json5 from "json5";
async function downloadVSCodeTheme(vscodeThemeId) {
  const [publisher, extId, theme] = vscodeThemeId.split(".");
  const themeLink = `https://${publisher}.gallery.vsassets.io/_apis/public/gallery/publisher/${publisher}/extension/${extId}/latest/assetbyname/Microsoft.VisualStudio.Services.VSIXPackage`;
  const buffer = await ofetch(themeLink, { responseType: "arrayBuffer" });
  const zip = await JSZip.loadAsync(buffer);
  const pkgContent = await zip.file("extension/package.json").async("string");
  const pkgJSON = JSON.parse(pkgContent);
  const themeConfig = (pkgJSON.contributes.themes || []).find(
    (t) => t.label.toLowerCase() === theme.toLowerCase()
  );
  if (!themeConfig) {
    const avaliableThemes = (pkgJSON.contributes.themes || []).map((t) => `\`${t.label}\``).join(" | ");
    throw new Error(`Not found theme \`${theme}\`, but found ${avaliableThemes}`);
  }
  const themePath = resolvePath(themeConfig.path, "extension/");
  const themeContent = await zip.file(themePath).async("string");
  const themeJSON = json5.parse(themeContent);
  return themeJSON;
}
function isDarkTheme(vscodeTheme) {
  var _a;
  if (vscodeTheme.type === "dark") {
    return true;
  }
  const background = (_a = vscodeTheme.colors) == null ? void 0 : _a["editor.background"];
  if (background && isDarkColor(background)) {
    return true;
  }
  return false;
}
function isDarkColor(color) {
  const hex = normalizeHexColor(color).replace(/#/, "");
  const [r, g, b] = hex.match(/.{2}/g).map((hex2) => parseInt(hex2, 16));
  const brightness = (r * 299 + g * 587 + b * 114) / 1e3;
  return brightness <= 155;
}
function normalizeHexColor(color) {
  let hex = color.replace(/#/, "");
  if (hex.length < 6) {
    hex = hex.split("").map((char) => char + char).join("");
  }
  return "#" + hex;
}

export {
  downloadVSCodeTheme,
  isDarkTheme
};
