"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/vscode.ts
var vscode_exports = {};
__export(vscode_exports, {
  downloadVSCodeTheme: () => downloadVSCodeTheme,
  isDarkTheme: () => isDarkTheme
});
module.exports = __toCommonJS(vscode_exports);
var import_jszip = __toESM(require("jszip"), 1);
var import_ofetch = require("ofetch");
var import_resolve_pathname = __toESM(require("resolve-pathname"), 1);
var import_json5 = __toESM(require("json5"), 1);
async function downloadVSCodeTheme(vscodeThemeId) {
  const [publisher, extId, theme] = vscodeThemeId.split(".");
  const themeLink = `https://${publisher}.gallery.vsassets.io/_apis/public/gallery/publisher/${publisher}/extension/${extId}/latest/assetbyname/Microsoft.VisualStudio.Services.VSIXPackage`;
  const buffer = await (0, import_ofetch.ofetch)(themeLink, { responseType: "arrayBuffer" });
  const zip = await import_jszip.default.loadAsync(buffer);
  const pkgContent = await zip.file("extension/package.json").async("string");
  const pkgJSON = JSON.parse(pkgContent);
  const themeConfig = (pkgJSON.contributes.themes || []).find(
    (t) => t.label.toLowerCase() === theme.toLowerCase()
  );
  if (!themeConfig) {
    const avaliableThemes = (pkgJSON.contributes.themes || []).map((t) => `\`${t.label}\``).join(" | ");
    throw new Error(`Not found theme \`${theme}\`, but found ${avaliableThemes}`);
  }
  const themePath = (0, import_resolve_pathname.default)(themeConfig.path, "extension/");
  const themeContent = await zip.file(themePath).async("string");
  const themeJSON = import_json5.default.parse(themeContent);
  return themeJSON;
}
function isDarkTheme(vscodeTheme) {
  var _a;
  if (vscodeTheme.type === "dark") {
    return true;
  }
  const background = (_a = vscodeTheme.colors) == null ? void 0 : _a["editor.background"];
  if (background && isDarkColor(background)) {
    return true;
  }
  return false;
}
function isDarkColor(color) {
  const hex = normalizeHexColor(color).replace(/#/, "");
  const [r, g, b] = hex.match(/.{2}/g).map((hex2) => parseInt(hex2, 16));
  const brightness = (r * 299 + g * 587 + b * 114) / 1e3;
  return brightness <= 155;
}
function normalizeHexColor(color) {
  let hex = color.replace(/#/, "");
  if (hex.length < 6) {
    hex = hex.split("").map((char) => char + char).join("");
  }
  return "#" + hex;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  downloadVSCodeTheme,
  isDarkTheme
});
